import { ValidationError } from 'class-validator';
import { eGraphicFieldType, eLights } from '../../../../consts';
import { AllowPrimitives } from '../../../../types';
import { RDocumentImagePage, iRDocumentImagePage } from './document-image-page.model';
/**
* Short version of image representation
*/
export interface iRDocumentImage {
    /**
    * Lighting scheme used to capture the image
    * @type {eLights}
    */
    light: eLights;
    /**
    * Field type
    * @type {eGraphicFieldType}
    */
    fieldType: eGraphicFieldType;
    /**
    * Image file name
    * @type {string}
    */
    name: string;
    /**
    * Image representation
    * @type {iRDocumentImagePage[]}
    */
    pages: iRDocumentImagePage[];
}
/**
* Short version of image representation
*/
export declare class RDocumentImage implements iRDocumentImage {
    /**
    * Lighting scheme used to capture the image
    * @type {eLights}
    */
    light: eLights;
    /**
    * Field type
    * @type {eGraphicFieldType}
    */
    fieldType: eGraphicFieldType;
    /**
    * Image file name
    * @type {string}
    */
    name: string;
    /**
    * Image representation
    * @type {iRDocumentImagePage[]}
    */
    pages: RDocumentImagePage[];
    /**
    * Create instance of RDocumentImage from plain object
    * @param {AllowPrimitives<iRDocumentImage>} input - plain object
    * @returns {RDocumentImage}
    */
    static fromPlain: (input: AllowPrimitives<iRDocumentImage>) => RDocumentImage;
    /**
    * Gets validation errors of RDocumentImage
    * @param {RDocumentImage} input - input data
    * @returns {ValidationError[]} - array of validation errors
    */
    static getValidationErrors: (input: RDocumentImage) => ValidationError[];
    /**
    * Check if RDocumentImage is valid
    * @param {RDocumentImage|RDocumentImage[]} input - input data
    * @returns {boolean}
    */
    static isValid: (input: RDocumentImage | RDocumentImage[]) => boolean;
}
